==> jc-1.4.0.tar.gz: polyglot/types/reflect/InnerClasses__24Info.h <==
// class polyglot.types.reflect.InnerClasses$Info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad8797b2c979db1f polyglot_types_reflect_InnerClasses__24Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_InnerClasses__24Info_H_
#define _JC_polyglot_types_reflect_InnerClasses__24Info_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs	_jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs	_jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$refs	_jc_polyglot_types_reflect_InnerClasses__24Info$refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs	_jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$object	_jc_polyglot_types_reflect_InnerClasses__24Info$object;

typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vmethods	_jc_polyglot_types_reflect_InnerClasses__24Info$vmethods;
typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtable	_jc_polyglot_types_reflect_InnerClasses__24Info$vtable;
typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtype	_jc_polyglot_types_reflect_InnerClasses__24Info$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_InnerClasses__24Info$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_reflect_InnerClasses__24Info$object *);

// Virtual methods structure
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vmethods	polyglot_types_reflect_InnerClasses__24Info;
};

// Vtype
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$refs {
    _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs	polyglot_types_reflect_InnerClasses__24Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs {
	jint	classIndex;
	jint	outerClassIndex;
	jint	nameIndex;
	jint	modifiers;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs	polyglot_types_reflect_InnerClasses__24Info;
};

// Object instance structure
struct _jc_polyglot_types_reflect_InnerClasses__24Info$object {
	_jc_polyglot_types_reflect_InnerClasses__24Info$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vtype	*vtype;
	_jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_InnerClasses__24Info$vtype _jc_polyglot_types_reflect_InnerClasses__24Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_InnerClasses__24Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_InnerClasses__24Info$class_object;

#endif	/* _JC_polyglot_types_reflect_InnerClasses__24Info_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/reflect/InnerClasses__24Info.h <==
// class polyglot.types.reflect.InnerClasses$Info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad8797b2c979db1f polyglot_types_reflect_InnerClasses__24Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_reflect_InnerClasses__24Info_H_
#define _JC_polyglot_types_reflect_InnerClasses__24Info_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs	_jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs	_jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$refs	_jc_polyglot_types_reflect_InnerClasses__24Info$refs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs	_jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs;
typedef struct _jc_polyglot_types_reflect_InnerClasses__24Info$object	_jc_polyglot_types_reflect_InnerClasses__24Info$object;

typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vmethods	_jc_polyglot_types_reflect_InnerClasses__24Info$vmethods;
typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtable	_jc_polyglot_types_reflect_InnerClasses__24Info$vtable;
typedef const struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtype	_jc_polyglot_types_reflect_InnerClasses__24Info$vtype;

// Constructors
extern void _jc_polyglot_types_reflect_InnerClasses__24Info$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_types_reflect_InnerClasses__24Info$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vmethods {
};

// Vtable
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vmethods	polyglot_types_reflect_InnerClasses__24Info;
};

// Vtype
struct _jc_polyglot_types_reflect_InnerClasses__24Info$vtype {
	_jc_type			type;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$refs {
    _jc_polyglot_types_reflect_InnerClasses__24Info$sub_refs	polyglot_types_reflect_InnerClasses__24Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs {
	jint	classIndex;
	jint	outerClassIndex;
	jint	nameIndex;
	jint	modifiers;
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_reflect_InnerClasses__24Info$sub_nonrefs	polyglot_types_reflect_InnerClasses__24Info;
};

// Object instance structure
struct _jc_polyglot_types_reflect_InnerClasses__24Info$object {
	_jc_polyglot_types_reflect_InnerClasses__24Info$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_reflect_InnerClasses__24Info$vtype	*vtype;
	_jc_polyglot_types_reflect_InnerClasses__24Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_reflect_InnerClasses__24Info$vtype _jc_polyglot_types_reflect_InnerClasses__24Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_reflect_InnerClasses__24Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_reflect_InnerClasses__24Info$class_object;

#endif	/* _JC_polyglot_types_reflect_InnerClasses__24Info_H_ */
